@@ -383,10 +383,19 @@ impl Controller {
                 Default::default()
             };
 
+            let folder = if let Some(parent) = input_test.parent() {
+                if let Some(parent_name) = parent.file_name() {
+                    if let Some(parent_unwrapped) = parent_name.to_str() {
+                        parent_unwrapped
+                    } else { Default::default() }
+                }else { Default::default() }
+            } else { Default::default() };
+
             // replace teh title and the body
             template_string
                 .replace("{title}", &title)
                 .replace("{body}", &processed)
+                .replace("{folder}", folder)
         } else {
             // no template, just return teh processed right back
             processed
